@@ -39,24 +39,12 @@ def set_files(f):
     global files
     files = f
 
-def init_write(file, subpath = 'temp', ext = 'txt', out = None):
-    global output_dir
-    out  = output_dir if out is None else out
-    path = os.path.join(out, subpath, f'{file}.{ext}') if subpath else os.path.join(out, f'{file}.{ext}')
+def init(file, subpath = 'temp', ext = 'txt'):
+    path = os.path.join(subpath, f'{file}.{ext}') if subpath else f'{file}.{ext}'
     if os.path.exists(path):
         os.remove(path)
     return open(path, 'a')
 
-def init_dict(file, subpath = 'temp', ext = 'txt'):
-    return {}
 
-def add_write(object, i, count):
+def add(object, i, count):
     object.write(f'{i} {count}\n')
-
-def add_dict(object, i, count):
-    object[i] = int(count)
-
-def set_memory(not_low_memory):
-    global init, add
-    init, add = [[init_write, add_write],
-                 [init_dict , add_dict  ]][not_low_memory]
\ No newline at end of file
